"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const React = __importStar(require("react"));
const model_1 = require("./model");
const Diff_1 = require("./Diff");
const apputils_1 = require("@jupyterlab/apputils");
const coreutils_1 = require("@jupyterlab/coreutils");
const typestyle_1 = require("typestyle");
/**
 * Method to open a main menu panel to show the diff of a given Notebook file.
 * If one already exists, just activates the existing one.
 *
 * @param path the path relative to the Jupyter server root.
 * @param app The JupyterLab application instance
 * @param diffContext the context in which the diff is being requested
 * @param renderMime the renderMime registry instance from the
 */
function openDiffView(path, app, diffContext, renderMime) {
    if (Diff_1.isDiffSupported(path)) {
        const id = `nbdiff-${path}-${model_1.getRefValue(diffContext.currentRef)}`;
        let mainAreaItems = app.shell.widgets('main');
        let mainAreaItem = mainAreaItems.next();
        while (mainAreaItem) {
            if (mainAreaItem.id === id) {
                app.shell.activateById(id);
                break;
            }
            mainAreaItem = mainAreaItems.next();
        }
        if (!mainAreaItem) {
            const nbDiffWidget = apputils_1.ReactWidget.create(React.createElement(Diff_1.RenderMimeProvider, { value: renderMime },
                React.createElement(Diff_1.Diff, { path: path, diffContext: diffContext })));
            nbDiffWidget.id = id;
            nbDiffWidget.title.label = coreutils_1.PathExt.basename(path);
            nbDiffWidget.title.iconClass = typestyle_1.style({
                backgroundImage: 'var(--jp-icon-diff)'
            });
            nbDiffWidget.title.closable = true;
            nbDiffWidget.addClass('jp-git-diff-parent-diff-widget');
            app.shell.add(nbDiffWidget, 'main');
            app.shell.activateById(nbDiffWidget.id);
        }
    }
    else {
        apputils_1.showDialog({
            title: 'Diff Not Supported',
            body: `Diff is not supported for ${coreutils_1.PathExt.extname(path).toLocaleLowerCase()} files.`
        });
    }
}
exports.openDiffView = openDiffView;
